/// <reference types="node" />
import { EventEmitter } from 'events';
import * as chromeUtil from './util/chrome';
export interface chromeConstructorOpts {
    flags?: chromeUtil.flags;
    cdp?: chromeUtil.cdp;
    timeout?: number;
}
export interface domOpts {
    wait?: boolean;
    timeout?: number;
}
export declare class Chrome extends EventEmitter {
    private cdp?;
    private flags?;
    private styleSheetsLoaded;
    private kill;
    private defaultTimeout;
    private navigatingPromise;
    private frameId;
    constructor(opts?: chromeConstructorOpts);
    private getChromeCDP();
    private runScript(script, async?);
    private simulateKeyPress(type?, key?, modifiers?);
    goto(url: string, opts?: {
        coverage: boolean;
        onload: boolean;
        timeout?: number;
    }): Promise<any>;
    evaluate(expression: Function, ...args: any[]): Promise<any>;
    screenshot(filePath?: string): Promise<void | Buffer>;
    pdf(filePath: string): Promise<void | Buffer>;
    size(width: number, height: number): Promise<boolean>;
    exists(selector: string, opts?: domOpts): Promise<boolean>;
    html(selector?: string, opts?: domOpts): Promise<string | null>;
    text(selector?: string, opts?: domOpts): Promise<string>;
    fetch(...args: any[]): Promise<any>;
    save(filePath?: string): Promise<boolean | string | null>;
    click(selector: string, opts?: domOpts): Promise<boolean>;
    focus(selector: string, opts?: domOpts): Promise<boolean>;
    type(selector: string, value: string, opts?: domOpts): Promise<boolean>;
    check(selector: string, opts?: domOpts): Promise<boolean>;
    uncheck(selector: string, opts?: domOpts): Promise<boolean>;
    select(selector: string, option: string, opts?: domOpts): Promise<boolean>;
    visible(selector: string, opts?: domOpts): Promise<boolean>;
    wait(waitParam: number | string, timeout?: number): Promise<any>;
    inject(src: string): Promise<boolean>;
    pageload(): Promise<boolean>;
    cookie(name?: string, value?: string): Promise<any>;
    attr(selector: string, attribute: string, opts?: domOpts): Promise<string | null>;
    coverage(src: string): Promise<{
        total: number;
        unused: number;
        percentUnused: number;
    } | Error>;
    done(): void;
}
